@@ -70,7 +70,7 @@ from calibre.utils.icu import numeric_sort_key
 from calibre.utils.imghdr import identify
 from calibre.utils.tdir_in_cache import tdir_in_cache
 from polyglot.builtins import (
-    iteritems, itervalues, map, string_or_bytes, unicode_type
+    as_bytes, iteritems, itervalues, map, string_or_bytes, unicode_type
 )
 from polyglot.urllib import urlparse
 
@@ -150,6 +150,8 @@ class Boss(QObject):
         self.gui.preview.split_requested.connect(self.split_requested)
         self.gui.preview.link_clicked.connect(self.link_clicked)
         self.gui.preview.render_process_restarted.connect(self.report_render_process_restart)
+        self.gui.preview.open_file_with.connect(self.open_file_with)
+        self.gui.preview.edit_file.connect(self.edit_file_requested)
         self.gui.check_book.item_activated.connect(self.check_item_activated)
         self.gui.check_book.check_requested.connect(self.check_requested)
         self.gui.check_book.fix_requested.connect(self.fix_requested)
@@ -1374,7 +1376,7 @@ class Boss(QObject):
         from calibre.gui2.open_with import run_program
         run_program(entry, dest.name, self)
         if question_dialog(self.gui, _('File opened'), _(
-            'When you are done editing {0} click "Update" to update'
+            'When you are done editing {0} click "Import" to update'
             ' the file in the book or "Discard" to lose any changes.').format(file_name),
             yes_text=_('Import'), no_text=_('Discard')
         ):
@@ -1401,9 +1403,9 @@ class Boss(QObject):
         }
         md.setUrls(list(map(QUrl.fromLocalFile, list(url_map.values()))))
         import json
-        md.setData(FILE_COPY_MIME, json.dumps({
+        md.setData(FILE_COPY_MIME, as_bytes(json.dumps({
             name: (url_map[name], container.mime_map.get(name)) for name in names
-        }))
+        })))
         QApplication.instance().clipboard().setMimeData(md)
 
     @in_thread_job
@@ -1411,6 +1413,7 @@ class Boss(QObject):
         md = QApplication.instance().clipboard().mimeData()
         if md.hasUrls() and md.hasFormat(FILE_COPY_MIME):
             import json
+            self.commit_all_editors_to_container()
             name_map = json.loads(bytes(md.data(FILE_COPY_MIME)))
             container = current_container()
             for name, (path, mt) in iteritems(name_map):
